import abc
import builtins
import datetime
import enum
import typing

import jsii
import publication
import typing_extensions

import aws_cdk.aws_lambda._jsii
import aws_cdk.core._jsii
import constructs._jsii

__jsii_assembly__ = jsii.JSIIAssembly.load(
    "@cloudcomponents/cdk-github-webhook",
    "1.0.79",
    __name__[0:-6],
    "cdk-github-webhook@1.0.79.jsii.tgz",
)

__all__ = [
    "__jsii_assembly__",
]

publication.publish()
